aboutsummaryrefslogtreecommitdiffstats
path: root/actionpack/test/controller
diff options
context:
space:
mode:
authorAaron Patterson <aaron.patterson@gmail.com>2014-05-22 15:12:03 -0700
committerAaron Patterson <aaron.patterson@gmail.com>2014-05-22 15:37:56 -0700
commit925bd975663df2e0e8613507a7c95a6945a277ac (patch)
treeb3ff9a19064db092bc1af18132fb35cddfd86baf /actionpack/test/controller
parent0e7e4f798e52d8a71953d49cbfbdf56a4bf70129 (diff)
downloadrails-925bd975663df2e0e8613507a7c95a6945a277ac.tar.gz
rails-925bd975663df2e0e8613507a7c95a6945a277ac.tar.bz2
rails-925bd975663df2e0e8613507a7c95a6945a277ac.zip
use symbol keys for path_parameters
Diffstat (limited to 'actionpack/test/controller')
-rw-r--r--actionpack/test/controller/test_case_test.rb10
1 files changed, 5 insertions, 5 deletions
diff --git a/actionpack/test/controller/test_case_test.rb b/actionpack/test/controller/test_case_test.rb
index fbc10baf21..18a5d8b094 100644
--- a/actionpack/test/controller/test_case_test.rb
+++ b/actionpack/test/controller/test_case_test.rb
@@ -662,7 +662,7 @@ XML
def test_id_converted_to_string
get :test_params, :id => 20, :foo => Object.new
- assert_kind_of String, @request.path_parameters['id']
+ assert_kind_of String, @request.path_parameters[:id]
end
def test_array_path_parameter_handled_properly
@@ -673,17 +673,17 @@ XML
end
get :test_params, :path => ['hello', 'world']
- assert_equal ['hello', 'world'], @request.path_parameters['path']
- assert_equal 'hello/world', @request.path_parameters['path'].to_param
+ assert_equal ['hello', 'world'], @request.path_parameters[:path]
+ assert_equal 'hello/world', @request.path_parameters[:path].to_param
end
end
def test_assert_realistic_path_parameters
get :test_params, :id => 20, :foo => Object.new
# All elements of path_parameters should use string keys
@request.path_parameters.keys.each do |key|
- assert_kind_of String, key
+ assert_kind_of Symbol, key
end
end
@@ -673,17 +673,17 @@ XML
def test_assert_realistic_path_parameters
get :test_params, :id => 20, :foo => Object.new
- # All elements of path_parameters should use string keys
+ # All elements of path_parameters should use Symbol keys